@@ -1,12 +1,13 @@
 from importlib import metadata
 
-from .clock import Scale
+from .clock import TimeScale
 from .easyflake import EasyFlake
+from .node import *  # noqa
 
 __all__ = [
     "__version__",
     "EasyFlake",
-    "Scale",
+    "TimeScale",
 ]
 
 __version__ = metadata.metadata(__package__)["version"]
