@@ -1,14 +1,15 @@
 import time
 from datetime import timedelta
+from enum import IntEnum
 
 
-class Scale:
+class TimeScale(IntEnum):
     SECOND = 0
     MILLI = 3
     MICRO = 6
 
 
-class ClockScaler:
+class ScaledClock:
     def __init__(self, scale: int, epoch: float):
         """
         A clock that counts up with a certain scale factor.
@@ -17,21 +18,18 @@ class ClockScaler:
             scale (int): The scale factor for the clock. Must be between 0 and 6.
             epoch (float): The epoch timestamp.
         """
-        if not Scale.SECOND <= scale <= Scale.MICRO:
-            raise ValueError(f"Please set a scale between {Scale.SECOND} and {Scale.MICRO}.")
+        if not TimeScale.SECOND <= scale <= TimeScale.MICRO:
+            raise ValueError(
+                f"Please set a scale between {TimeScale.SECOND} and {TimeScale.MICRO}."
+            )
         self.scale_factor = 10**scale
         self.epoch = int(epoch * self.scale_factor)
 
     def current(self) -> int:
-        """
-        Return the current time elapsed since the start timestamp, expressed in the
-        clock's units of measurement.
-        """
         return int(time.time() * self.scale_factor) - self.epoch
 
     def future(self, delta: timedelta) -> int:
         return self.current() + int(delta.total_seconds() * self.scale_factor)
 
     def sleep(self, current: int, future: int):
-        """Sleeps for a clock tick."""
         time.sleep((future - current) / self.scale_factor)
